@@ -8,9 +8,9 @@ from sqlalchemy import Column, Integer, String, Boolean, distinct, and_
 from config_rss import *
 from modules import *
 from rumpy import RumClient
-from rumpy.client.module_op import BaseDB
-from rumpy.client.module.base import Base
-from rumpy.client.utils import ts2datetime
+from rumpy.module_op import BaseDB
+from rumpy.modules.base import Base
+from rumpy.utils import ts2datetime
 
 sys.path.insert(1, mixin_sdk_dirpath)
 from mixinsdk.clients.http_client import HttpClient_AppAuth
@@ -32,8 +32,12 @@ class RssBot:
         self.db = BaseDB("rss_bot_test", echo=False, reset=False)
         self.check_groups()
         self.groups = self.db.session.query(BotRumGroups).all()
-        self.update_all_profiles()
-        self.count_users()
+        self.update_all_profiles("bot")
+
+    def reconnect(self):
+        print(datetime.datetime.now(), "http reconnect...")
+        self.xin = HttpClient_AppAuth(self.config)
+        print(datetime.datetime.now(), "http reconnect done")
 
     def update_profiles(self, group_id):
         self.rum.group_id = group_id
@@ -42,18 +46,15 @@ class RssBot:
 
         if progress == None:
             _p = {"progress_type": "GET_PROFILES", "trx_id": None, "timestamp": None, "group_id": group_id}
-            print(_p)
             self.db.add(BotRumProgress(_p))
 
         p_tid = None if progress == None else progress.trx_id
-        print(datetime.datetime.now(), "update_profiles", group_id, p_tid)
 
         data = self.rum.group.get_users_profiles({"trx_id": p_tid}, ("name", "wallet"))
         tid = data.get("trx_id")
         ts = data.get("trx_timestamp")
 
         if tid and tid != p_tid:
-            print(tid, ts)
             self.db.session.query(BotRumProgress).filter(_x).update({"trx_id": tid, "timestamp": ts})
             self.db.session.commit()
 
@@ -74,14 +75,17 @@ class RssBot:
                 if _wallet != existd.wallet:
                     _p["wallet"] = _wallet
 
-                self.db.session.query(BotRumProfiles).filter(-x).update(_p)
+                self.db.session.query(BotRumProfiles).filter(_x).update(_p)
                 self.db.commit()
 
-    def update_all_profiles(self):
-
-        for g in self.groups:
-            print(datetime.datetime.now(), g.minutes, g.group_id, g.group_name)
-            self.update_profiles(g.group_id)
+    def update_all_profiles(self, where="bot"):
+        if where == "bot":
+            for g in self.groups:
+                # print(datetime.datetime.now(), g.minutes, g.group_id, g.group_name)
+                self.update_profiles(g.group_id)
+        elif where == "node":
+            for group_id in self.rum.node.groups_id:
+                self.update_profiles(group_id)
 
     def check_groups(self):
 
@@ -92,7 +96,7 @@ class RssBot:
                 self.rum.group_id = _gid
 
                 existd = self.db.session.query(BotRumGroups).filter(BotRumGroups.group_id == _gid).first()
-                _m = commands[k].get("minutes") or -30
+                _m = commands[k].get("minutes") or default_minutes
                 if existd is None:
                     _p = {
                         "group_id": _gid,
@@ -104,21 +108,6 @@ class RssBot:
                     self.db.session.query(BotRumGroups).filter(BotRumGroups.group_id == _gid).update({"minutes": _m})
                     self.db.commit()
 
-    def count_users(self):
-
-        print("🤖 Rss Rum to Xin bot 7000104017 🤖")
-        print("=== 每个种子网络的订阅数 ===")
-        counts = {}
-        for g in self.groups:
-            _c = self.db.session.query(BotRss).filter(BotRss.group_id == g.group_id).all()
-            counts[g.group_name] = len(_c)
-        countsit = sorted(counts.items(), key=lambda x: x[1], reverse=True)
-        for name, n in countsit:
-            print(n, name)
-
-        _c = self.db.session.query(BotRss).filter(BotRss.user_id).all()
-        print("🥂 共计", len(_c), "个用户使用 bot🥂")
-
     def get_nicknames(self, group_id):
         _nn = self.db.session.query(BotRumProfiles).filter(BotRumProfiles.group_id == group_id).all()
         nicknames = {}
@@ -145,7 +134,7 @@ class RssBot:
             gname = g.group_name
             minutes = self.db.session.query(BotRumGroups.minutes).filter(BotRumGroups.group_id == g.group_id).first()
             if minutes[0] is None:
-                minutes = -15
+                minutes = default_minutes
             else:
                 minutes = minutes[0]
             if not existd:
@@ -204,32 +193,16 @@ class RssBot:
         print(datetime.datetime.now(), "send_msg_to_xin ...")
         rss = self.db.session.query(BotRss).all()
 
-        """ 
-        # test:我订阅所有
-        for g in self.groups:
-            user_id = "bae95683-eabb-422f-9588-24dadffd0323"  # "b807ebea-4b46-4cf6-89c5-3a810ba9d32e"
-            conversation_id = "e81c28a6-47aa-3aa0-97d2-62ac1754c90f"
-            _d = {
-                "user_id": user_id,
-                "group_id": g.group_id,
-                "is_rss": True,
-                "user_group": user_id + g.group_id,
-                "conversation_id": conversation_id,
-            }
-            self.db.add(BotRss(_d))
-        """
-
         for r in rss:
-            # if r.conversation_id != my_conversation_id:
-            #    continue
-
+            if r.is_rss != True:
+                continue
             gid = r.group_id
             uid = r.user_id
             _g = self.db.session.query(BotRumGroups).filter(BotRumGroups.group_id == gid).first()
             if _g:
                 minutes = _g.minutes
             else:
-                minutes = -15
+                minutes = default_minutes
             nice_ts = str(datetime.datetime.now() + datetime.timedelta(minutes=minutes))
             trxs = self.db.session.query(BotTrxs).filter(BotTrxs.group_id == gid).all()
             if len(trxs) == 0:
@@ -271,7 +244,7 @@ class RssBot:
                 msg = pack_message(pack_text_data(trx.text), r.conversation_id)
 
                 resp = self.xin.api.send_messages(msg)
-                # print(datetime.datetime.now(), r.conversation_id, trx.text[:30].replace("\n", " "), "...")
+                print(datetime.datetime.now(), r.conversation_id, "..." + trx.text[10:30] + "...")
 
                 if "data" in resp:
                     _d = {
@@ -282,15 +255,30 @@ class RssBot:
                         "is_sent": True,
                     }
                     self.db.add(BotTrxsSent(_d))
+                else:
+                    print(resp)
+                    self.reconnect()
 
         print(datetime.datetime.now(), "send_msg_to_xin done.")
 
     def send_to_rum(self, group_id=my_rum_group):
         self.rum.group_id = group_id
-        data = self.db.session.query(BotComments).filter(BotComments.is_to_rum == False).all()
+        data = (
+            self.db.session.query(BotComments)
+            .filter(
+                and_(
+                    BotComments.user_id == my_user_id,
+                    BotComments.text.like("代发%"),
+                    BotComments.is_to_rum != True,
+                )
+            )
+            .all()
+        )
         for r in data:
             resp = self.rum.group.send_note(content=r.text[3:])
+            print(datetime.datetime.now(), "send_to_rum", r.text[3:10] + "...")
             if "trx_id" not in resp:
+                print(datetime.datetime.now(), "send_to_rum ERROR", resp)
                 continue
             self.db.session.query(BotComments).filter(BotComments.message_id == r.message_id).update(
                 {"is_to_rum": True}
@@ -298,19 +286,22 @@ class RssBot:
             self.db.commit()
 
     def do_rss(self):
+        self.update_all_profiles("bot")
         self.send_to_rum()
         self.send_msg_to_xin()
         self.get_trxs_from_rum()
 
     def get_reply_text(self, text):
+        if type(text) == str and text.lower() in ["hi", "hello", "你好", "订阅"]:
+            return welcome_text, None
         try:
             _num = int(text)
             _abs = abs(_num)
         except:
-            return welcome_text, None
+            return "输入 hi 查看操作说明", None
 
         if str(_abs) not in list(commands.keys()):
-            return welcome_text, None
+            return "输入 hi 查看操作说明", None
 
         irss = {}  # init
         for g in self.groups:
@@ -328,15 +319,14 @@ class RssBot:
         else:
             # 修改订阅：增加或推定
             self.rum.group_id = _gidx
-            print(_gidx)
-            _gname = self.rum.group.seed().get("group_name")
+            _gname = commands[str(_abs)]["text"]
             if _num > 0:
                 irss[_gidx] = True
-                reply_text = f"✅ Yes，您已成功订阅 {_gname}{rum_adds}"
+                reply_text = f"✅ Yes，您已成功{_gname}{rum_adds}"
             else:
                 # 取消订阅
                 irss[_gidx] = False
-                reply_text = f"👌 Ok，您已取消订阅{_gname}{rum_adds}"
+                reply_text = f"👌 Ok，您已取消{_gname}{rum_adds}"
         return reply_text, irss
 
     def update_rss(self, user_id, irss):
@@ -349,7 +339,7 @@ class RssBot:
                 if irss[group_id] != None and existd.is_rss != irss[group_id]:
                     self.db.session.query(BotRss).filter(BotRss.user_group == ug).update({"is_rss": irss[group_id]})
                     self.db.commit()
-
+                print(datetime.datetime.now(), "update rss", group_id, irss[group_id])
             else:
                 data = {
                     "user_id": user_id,
@@ -359,6 +349,7 @@ class RssBot:
                     "conversation_id": self.xin.get_conversation_id_with_user(user_id),
                 }
                 self.db.add(BotRss(data))
+                print(datetime.datetime.now(), "add rss", group_id, irss[group_id])
 
     def check_str_param(self, text):
         if type(text) == str:
@@ -389,11 +380,11 @@ class RssBot:
             and msgview.data_decoded.startswith("代发：")
         )
         if is_to_rum:
-
             self.db.session.query(BotComments).filter(BotComments.message_id == msgview.message_id).update(
                 {"is_reply": True, "is_to_rum": False}
             )
             self.db.commit()
+            print(datetime.datetime.now(), "新增代发：", msgview.data_decoded[3:10] + "...")
         return is_to_rum
 
     def counts_trxs(self, days=-1, num=100):
@@ -411,9 +402,11 @@ class RssBot:
         """
 
         thatday = datetime.datetime.now().date() + datetime.timedelta(days=days)
-
+        counts_result = {"data": {}, "date": str(thatday)}
         while True:
             _trxs = self.rum.group.content_trxs(is_reverse=True, num=num)
+            if len(_trxs) == 0:
+                return counts_result
             lastest_day = ts2datetime(_trxs[-1]["TimeStamp"]).date()
             if lastest_day < thatday:
                 counts = {}
@@ -433,14 +426,14 @@ class RssBot:
 
         return counts_result
 
-    def airdrop_to_group(self, group_id, num_trxs=1, days=-1):
+    def airdrop_to_group(self, group_id, num_trxs=1, days=-1, memo=None):
         self.rum.group_id = group_id
         group_name = self.rum.group.seed().get("group_name")
         print(datetime.datetime.now(), group_id, group_name, "...")
 
         counts_result = self.counts_trxs(days=days)
         date = datetime.datetime.now().date() + datetime.timedelta(days=days)
-        memo = f"{date} Rum 种子网络空投"
+        memo = memo or f"{date} Rum 种子网络空投"
         for pubkey in counts_result["data"]:
             # trxs 条数够了
             if counts_result["data"][pubkey] < num_trxs:
@@ -462,12 +455,12 @@ class RssBot:
                 if sent:  # 用钱包排重，不重复空投
                     continue
 
-                _num = str(round(0.001 + random.randint(1, 100) / 1000000, 6))
+                _num = str(round(rum_reward_base + random.randint(1, 300) / 1000000, 6))
                 _a = {
                     "mixin_id": existd.wallet,
                     "group_id": group_id,
                     "pubkey": pubkey,
-                    "num": str(_num),
+                    "num": _num,
                     "token": "RUM",
                     "memo": memo,
                     "is_sent": False,
@@ -475,12 +468,12 @@ class RssBot:
                 r = self.xin.api.transfer.send_to_user(existd.wallet, rum_asset_id, _num, memo)
 
                 if "data" in r:
-                    print(existd.wallet, str(_num), "账户余额：", r.get("data").get("closing_balance"))
+                    print(existd.wallet, _num, "账户余额：", r.get("data").get("closing_balance"))
                     _a["is_sent"] = True
 
                 self.db.add(BotAirDrops(_a))
 
-    def airdrop_to_node(self, num_trxs=1, days=-1):
+    def airdrop_to_node(self, num_trxs=1, days=-1, memo=None):
         for group_id in self.rum.node.groups_id:
             self.airdrop_to_group(group_id, num_trxs, days)
 
@@ -489,7 +482,9 @@ class RssBot:
         memo = memo or f"{_today} Rum 订阅器空投"
         users = self.db.session.query(distinct(BotRss.user_id)).all()
         for user in users:
-            print(user)
+            if len(users) < 1:
+                continue
+            user = user[0]
             sent = (
                 self.db.session.query(BotAirDrops)
                 .filter(and_(BotAirDrops.mixin_id == user, BotAirDrops.memo == memo))
@@ -498,11 +493,11 @@ class RssBot:
             if sent:  # 用钱包排重，不重复空投
                 continue
 
-            _num = str(round(0.00001 + random.randint(1, 10) / 1000000, 6))
+            _num = str(round(rum_reward_base + random.randint(1, 300) / 1000000, 6))
             r = self.xin.api.transfer.send_to_user(user, rum_asset_id, _num, memo)
-            _a = {"mixin_id": user, "num": str(_num), "token": "RUM", "memo": memo, "is_sent": False}
+            _a = {"mixin_id": user, "num": _num, "token": "RUM", "memo": memo, "is_sent": False}
             if "data" in r:
-                print(user, str(_num), "账户余额：", r.get("data").get("closing_balance"))
+                print(user, _num, "账户余额：", r.get("data").get("closing_balance"))
                 _a["is_sent"] = True
 
             self.db.add(BotAirDrops(_a))
